﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using TransportCompanyContracts.BindingModels;
using TransportCompanyContracts.SearchModels;
using TransportCompanyContracts.StoragesContracts;
using TransportCompanyContracts.ViewModels;
using TransportCompanyDatabaseImplements.Models;

namespace TransportCompanyDatabaseImplements.Implements
{
	public class ClientStorage : IClientStorage
	{
		public List<ClientViewModel> GetFullList()
		{
			using var context = new ElegevContext();

			return context.Clients
				.Select(x => x.GetViewModel)
				.ToList();
		}

		public List<ClientViewModel> GetFilteredList(ClientSearchModel model)
		{
			if (!model.Id.HasValue)
			{
				return new();
			}

			using var context = new ElegevContext();

			return context.Clients
				.Where(x => x.Id == model.Id)
				.Select(x => x.GetViewModel)
				.ToList();
		}

		public ClientViewModel? GetElement(ClientSearchModel model)
		{
			if (string.IsNullOrEmpty(model.Name) && !model.Id.HasValue)
			{
				return null;
			}

			using var context = new ElegevContext();

			return context.Clients
				.FirstOrDefault(x => (model.Id.HasValue && x.Id == model.Id))
				?.GetViewModel;
		}

		public ClientViewModel? Insert(ClientBindingModel model)
		{
			using var context = new ElegevContext();

			model.Id = context.Clients.Count() > 0 ? context.Clients.Max(x => x.Id) + 1 : 1;

			var newClient = Client.Create(model);

			if (newClient == null)
			{
				return null;
			}

			context.Clients.Add(newClient);
			context.SaveChanges();

			return newClient.GetViewModel;
		}

		public ClientViewModel? Update(ClientBindingModel model)
		{
			using var context = new ElegevContext();
			using var transaction = context.Database.BeginTransaction();

			try
			{
				var client = context.Clients.FirstOrDefault(rec => rec.Id == model.Id);

				if (client == null)
				{
					return null;
				}

				client.Update(model);
				context.SaveChanges();
				transaction.Commit();

				return client.GetViewModel;
			}
			catch
			{
				transaction.Rollback();
				throw;
			}
		}

		public ClientViewModel? Delete(ClientBindingModel model)
		{
			using var context = new ElegevContext();

			var element = context.Clients
				.FirstOrDefault(rec => rec.Id == model.Id);

			if (element != null)
			{
				context.Clients.Remove(element);
				context.SaveChanges();

				return element.GetViewModel;
			}

			return null;
		}
	}
}
